============================================================================
``torch-adf``: Assumed Density Filtering (ADF) Probabilistic Neural Networks
============================================================================

Release v\ |release| (`What's new? <changelog>`).

.. include:: ../README.rst
   :start-after: teaser-start
   :end-before: teaser-end


Getting Started
===============

``torch-adf`` is a Python package `hosted on PyPI <https://pypi.org/project/torch-adf/>`_.
It is intended to be used as part of the PyTorch framework.
The recommended installation method is `pip <https://pip.pypa.io/en/stable/>`_-installing
into a virtual environment.

.. code-block:: console

   $ pip install torch-adf

The next three steps should bring you up and running in no time:

- The `overview` section will show you a simple example of ``torch-adf`` in action and
  introduce you to its core ideas.
- The `examples` section will give you a comprehensive tour of ``torch-adf``'s features.
  After reading, you will know about advanced features and how to use them.
- The `api` reference is a quick way to look up details of all features and their options.
- If at any point you get confused by some terminology, please check out our `glossary`.


.. include:: ../README.rst
   :start-after: project-info-start
   :end-before: project-info-end

.. toctree::
  :maxdepth: 1

  license
  contributing
  changelog

.. include:: ../README.rst
  :start-after: literature-start
  :end-before: literature-end


----


Full Table of Contents
======================

.. toctree::
   :maxdepth: 2

   overview
   examples
   api
   glossary


Indices and Search
==================

* `genindex`
* `search`
